@@ -29,7 +29,7 @@
 
 class install : public InstallDialog
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
