@@ -8,8 +8,8 @@
 		_buffer = TQString();
 		_process = new TDEProcess();
 	
-		connect(_process, TQT_SIGNAL(receivedStdout(TDEProcess*, char*, int)),
-			this, TQT_SLOT(slotProcessOutput(TDEProcess*, char*, int)));
+		connect(_process, TQ_SIGNAL(receivedStdout(TDEProcess*, char*, int)),
+			this, TQ_SLOT(slotProcessOutput(TDEProcess*, char*, int)));
 	
 	}
 	
@@ -59,5 +59,5 @@
 		_buffer.append(TQString::fromLocal8Bit(buffer, len));
 	}
 
-
+#include "process.moc"
 
